ParameterEstimationComposition
==============================

.. container:: related

    *Related*

    .. toctree::
       :maxdepth: 1

       OptimizationControlMechanism

.. toctree::
   :maxdepth: 2

.. automodule:: psyneulink.core.compositions.parameterestimationcomposition
   :members:
   :private-members:
   :exclude-members: _validate_params, run, evaluate
